@@ -1,9 +1,9 @@
 import tarfile
 from pathlib import Path
 
-from click import prompt, secho
+from click import confirm, prompt, secho
 
-from indico_install.utils import convertb64, run_cmd, find_gcs_key
+from indico_install.utils import convertb64, find_gcs_key, run_cmd
 
 
 def auth_with_gsutil(deployment_root, raise_missing_key=False):
@@ -38,18 +38,21 @@ def postgres_input(conf):
 
 def download_indicoapi_data(deployment_root, version=None, extract=True):
     indicoapi_version = version or prompt(
-        "Version of api model data to download", default="v7"
+        "Version of api model data to download", default="v10"
     )
     indicoapi_tar = f"indicoapi_data_{indicoapi_version}.tar.gz"
 
     tar_path = Path(deployment_root) / indicoapi_tar
     data_path = Path(deployment_root) / f"indicoapi_data_{indicoapi_version}"
-    if not data_path.exists():
+    if not data_path.exists() or confirm(
+        f"Overwrite existing directory {data_path}", default=True
+    ):
         if tar_path.exists():
             secho(f"Skipping download - using {tar_path}", fg="yellow")
         else:
             run_cmd(
-                f"mkdir -p {data_path} && gsutil cp gs://indicoapi-data/{indicoapi_tar} {deployment_root}"
+                f"mkdir -p {data_path} && "
+                f"gsutil cp -r gs://indicoapi-data/{indicoapi_tar} {deployment_root}"
             )
             assert tar_path.exists(), "Unable to download indicoapi_data successfully"
         if extract:
@@ -60,10 +63,5 @@ def download_indicoapi_data(deployment_root, version=None, extract=True):
         else:
             secho("Please extract and upload TAR {tar_path} when ready")
             return
-    else:
-        secho(
-            f"Skipping indicoapi data download - already exists at {data_path}",
-            fg="yellow",
-        )
 
     return data_path
