@@ -172,9 +172,7 @@ def edit_configmap(
 
 @updraft.command("restore")
 @click.pass_context
-@click.option(
-    "--keep-images", is_flag=True, help=f"Keep the current deployed images",
-)
+@click.option("--keep-images", is_flag=True, help=f"Keep the current deployed images")
 @options_wrapper()
 def restore_version(ctx, deployment_root, yes, keep_images=False):
     """
